class SignalCli < Formula
  desc "CLI and dbus interface for WhisperSystems/libsignal-service-java"
  homepage "https://github.com/AsamK/signal-cli"
  url "https://github.com/AsamK/signal-cli/archive/refs/tags/v0.13.13.tar.gz"
  sha256 "ac1be9c1f9b2a154e9127c086a5bc889e172881bf62701652dc58f1119dbf095"
  license "GPL-3.0-or-later"

  bottle do
    sha256 cellar: :any_skip_relocation, arm64_sequoia: "c0f6d05c2de6821d29c54f5f527a55492448ca13a740a03b8bd3f019f7a82f99"
    sha256 cellar: :any_skip_relocation, arm64_sonoma:  "b5c02019ff72bf9bd158ddd1b260b6d63adc414074b0355f85048cdc7ef723a5"
    sha256 cellar: :any_skip_relocation, arm64_ventura: "128848653f79a13448142ccf4e5866fc4674d3b38797b66c04ca306231a1f923"
    sha256 cellar: :any_skip_relocation, sonoma:        "44816f11765f4effde498b4b54313b561a806027610460191faea8effad4df50"
    sha256 cellar: :any_skip_relocation, ventura:       "0d583713fd44790bafbc92acc675753bd7a2ac7d6cff4e404123c9153369774b"
    sha256 cellar: :any_skip_relocation, arm64_linux:   "ea773757c6e71802b3d30c573f26a8f4b50e3aa2eba6d1973f750d7d15d1866f"
    sha256 cellar: :any_skip_relocation, x86_64_linux:  "8d6b1fa2f45ba7d86df54f80d4e0121ef0cbb370337967d9a07ddcaad3fa88fc"
  end

  depends_on "cmake" => :build # For `boring-sys` crate in `libsignal-client`
  depends_on "gradle" => :build
  depends_on "protobuf" => :build
  depends_on "rust" => :build

  depends_on "openjdk@21"

  uses_from_macos "llvm" => :build # For `libclang`, used by `boring-sys` crate
  uses_from_macos "zip" => :build

  # https://github.com/AsamK/signal-cli/wiki/Provide-native-lib-for-libsignal#determine-the-required-libsignal-client-version
  # To check the version of `libsignal-client`, run:
  # url=https://github.com/AsamK/signal-cli/releases/download/v$version/signal-cli-$version.tar.gz
  # curl -fsSL $url | tar -tz | grep libsignal-client
  resource "libsignal-client" do
    url "https://github.com/signalapp/libsignal/archive/refs/tags/v0.66.2.tar.gz"
    sha256 "dd5958d6242cd1d7794bccdb62b2538c73c7a091214f502f0930caf80d781bd5"
  end

  def install
    ENV["JAVA_HOME"] = Language::Java.java_home("21")
    system "gradle", "build"
    system "gradle", "installDist"
    libexec.install (buildpath/"build/install/signal-cli").children
    (libexec/"bin/signal-cli.bat").unlink
    (bin/"signal-cli").write_env_script libexec/"bin/signal-cli", Language::Java.overridable_java_home_env("21")

    resource("libsignal-client").stage do |r|
      # https://github.com/AsamK/signal-cli/wiki/Provide-native-lib-for-libsignal#manual-build

      libsignal_client_jar = libexec.glob("lib/libsignal-client-*.jar").first
      embedded_jar_version = Version.new(libsignal_client_jar.to_s[/libsignal-client-(.*)\.jar$/, 1])
      res = r.resource
      odie "#{res.name} needs to be updated to #{embedded_jar_version}!" if embedded_jar_version != res.version

      # rm originally-embedded libsignal_jni lib
      system "zip", "-d", libsignal_client_jar, "libsignal_jni_*.so", "libsignal_jni_*.dylib", "signal_jni_*.dll"

      # build & embed library for current platform
      cd "java" do
        inreplace "settings.gradle", "include ':android'", ""
        system "./build_jni.sh", "desktop"
        cd "client/src/main/resources" do
          arch = Hardware::CPU.intel? ? "amd64" : "aarch64"
          system "zip", "-u", libsignal_client_jar, shared_library("libsignal_jni_#{arch}")
        end
      end
    end
  end

  test do
    # test 1: checks class loading is working and version is correct
    output = shell_output("#{bin}/signal-cli --version")
    assert_match "signal-cli #{version}", output

    # test 2: ensure crypto is working
    begin
      io = IO.popen("#{bin}/signal-cli link", err: [:child, :out])
      sleep 24
    ensure
      Process.kill("SIGINT", io.pid)
      Process.wait(io.pid)
    end
    assert_match "sgnl://linkdevice?uuid=", io.read
  end
end
