class Sloth < Formula
  desc "Prometheus SLO generator"
  homepage "https://sloth.dev/"
  url "https://github.com/slok/sloth/archive/refs/tags/v0.12.0.tar.gz"
  sha256 "783689544f1829cb139ab3bbdd5e53cc835469a92c4a187384ff51f08eceb284"
  license "Apache-2.0"
  head "https://github.com/slok/sloth.git", branch: "main"

  livecheck do
    url :stable
    regex(/^v?(\d+(?:\.\d+)+)$/i)
  end

  bottle do
    sha256 cellar: :any_skip_relocation, arm64_sequoia: "76a59c6254842dd76f9020868f4ec38388e645039ef51077192d1f5f0fe573d9"
    sha256 cellar: :any_skip_relocation, arm64_sonoma:  "6e37e3ca543f2167c514db79724840c8174179f8c465b114a94e8a717d7ff56e"
    sha256 cellar: :any_skip_relocation, arm64_ventura: "b93c679c5217405d26f967617e4de9b35fd5ae0c57814a4fc00302481023bd0b"
    sha256 cellar: :any_skip_relocation, sonoma:        "95fd259914b02afb9489548a2420594eaeafc2afeebbe8d8772e37a5b3101036"
    sha256 cellar: :any_skip_relocation, ventura:       "1b9c32ba8aa94c9f087fee074c651c7540bd66b11b0d1966d66b79e6fafccc87"
    sha256 cellar: :any_skip_relocation, x86_64_linux:  "6ee5d6b1c4cb80ee6b90d2f6081a2adc59d952ef3515599b00e8f0a4aa7bb047"
  end

  depends_on "go" => :build

  def install
    ldflags = "-s -w -X github.com/slok/sloth/internal/info.Version=#{version}"
    system "go", "build", *std_go_args(ldflags:), "./cmd/sloth"

    pkgshare.install "examples"
  end

  test do
    test_file = pkgshare/"examples/getting-started.yml"

    output = shell_output("#{bin}/sloth validate -i #{test_file} 2>&1")
    assert_match "Validation succeeded", output

    output = shell_output("#{bin}/sloth generate -i #{test_file} 2>&1")
    assert_match "SLO alert rules generated", output
    assert_match "Code generated by Sloth", output

    assert_match version.to_s, shell_output("#{bin}/sloth version")
  end
end
