class Uv < Formula
  desc "Extremely fast Python package installer and resolver, written in Rust"
  homepage "https://docs.astral.sh/uv/"
  url "https://github.com/astral-sh/uv/archive/refs/tags/0.6.12.tar.gz"
  sha256 "e0d30e841d53b4adf46b00394036b9fed595aa778f42492c28d51a7e1567fd6b"
  license any_of: ["Apache-2.0", "MIT"]
  head "https://github.com/astral-sh/uv.git", branch: "main"

  bottle do
    sha256 cellar: :any_skip_relocation, arm64_sequoia: "cbc1240fc60f935d05e7dedba648376133d917f5438e5422648d492d8890284e"
    sha256 cellar: :any_skip_relocation, arm64_sonoma:  "730293772d1d64df8e3c06a085bc89362cf1bb94d6e50815830a266a83d8aaa2"
    sha256 cellar: :any_skip_relocation, arm64_ventura: "a48349f965ccd284a3d79dd26b1812078486ecdbae0ede2aa21bb88767f5b790"
    sha256 cellar: :any_skip_relocation, sonoma:        "7aecf7d6ed7e06b059dca923a0e67db05f2dd5dce6b136628abd39239e2e10a9"
    sha256 cellar: :any_skip_relocation, ventura:       "2114008574ecfece75874f55cf147872ffbea18c7cf3fc03707b5cf108ccdd30"
    sha256 cellar: :any_skip_relocation, arm64_linux:   "5f0d1d11d4b9dc9901d8cb87d65c95262dfb9accb124c23b97ffeab63dc8bb52"
    sha256 cellar: :any_skip_relocation, x86_64_linux:  "544d263e9c73ae390a2f049d59240cad7b3757fa3d0690ab030b64a78b41898b"
  end

  depends_on "pkgconf" => :build
  depends_on "rust" => :build

  uses_from_macos "python" => :test
  uses_from_macos "bzip2"
  uses_from_macos "xz"

  def install
    ENV["UV_COMMIT_HASH"] = ENV["UV_COMMIT_SHORT_HASH"] = tap.user
    ENV["UV_COMMIT_DATE"] = time.strftime("%F")
    system "cargo", "install", "--no-default-features", *std_cargo_args(path: "crates/uv")
    generate_completions_from_executable(bin/"uv", "generate-shell-completion")
    generate_completions_from_executable(bin/"uvx", "--generate-shell-completion")
  end

  test do
    (testpath/"requirements.in").write <<~REQUIREMENTS
      requests
    REQUIREMENTS

    compiled = shell_output("#{bin}/uv pip compile -q requirements.in")
    assert_match "This file was autogenerated by uv", compiled
    assert_match "# via requests", compiled

    assert_match "ruff 0.5.1", shell_output("#{bin}/uvx -q ruff@0.5.1 --version")
  end
end
